"""Common configuration constants
"""

PROJECTNAME = 'Products.humanator'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'Humanator question': 'Products.humanator: Add Humanator question',
    'Humanator folder': 'Products.humanator: Add Humanator folder',
}